$LavaFireTime = 1200; //Tamper with this and you can alter the number of fire emitters out at once.
package lavadamage //Normally, if a player falls in the lava, damage is done to them at a fast, but still unrealistic rate. So here we make it so our lava works differently.
{
	function Armor::onEnterLiquid(%this, %obj, %coverage, %type)
	{
		if(%type == 4)
		{
			%obj.damage(%obj, %obj.gettransform(), 10000, $damagetype::fall); //10000 damage should be enough to kill most anything that falls in. I use fall damage because I'm too lazy to make my own damage type and generic gets old.
			%obj.addVelocity("0 0 300"); //I need to decide between a dramatic sinking into the lava, and a comedic shot into the air. Since I couldn't get the water physics right to do the sinking, and since vehicles would still either bounce out or fall through instantly anyway, the bounce effect won out. [/paragraphLongCommentary]
			%obj.burn(10); //What would a death by burning be without a playerburn?
		} //Fun fact: Invincible players won't be hurt by this, but they will still be launched into the air and burned.
		else //Too bad the only time this effect will be seen is if someone goes really far out, or they tamper with the map.
			parent::onEnterLiquid(%this, %obj, %coverage, %type); //In case they change the map to some other place with lava. That's their problem.
	}
};
activatePackage(lavadamage);

datablock ParticleData(LavaFireParticle)
{
	dragCoefficient      = 4.5;
	gravityCoefficient   = -3;
	inheritedVelFactor   = 0;
	constantAcceleration = 0.2;
	lifetimeMS           = 1150;
	lifetimeVarianceMS   = 320;
	textureName          = "base/data/particles/cloud";
	spinSpeed		= 4.0;
	spinRandomMin		= -40.0;
	spinRandomMax		= 40.0;
	colors[0]	= "0.7 0.1 0.1 0.9";
	colors[1]	= "0.7 0.6 0.1 0.8";
	colors[2]	= "0.9 0.9 0.9 0.55";
	sizes[0]	= 0.8;
	sizes[1]	= 2.4;
	sizes[2]	= 2.8;
	times[0]	= 0;
	times[1]	= 0.2;
	times[2]	= 1;

	useInvAlpha = false;
};

datablock ParticleEmitterData(LavafireEmitter)
{
   ejectionPeriodMS = 3;
   periodVarianceMS = 0;
   ejectionVelocity = 21;
   velocityVariance = 7;
   ejectionOffset   = 0;
   thetaMin         = 0;
   thetaMax         = 25;
   phiReferenceVel  = 0;
   phiVariance      = 360;
   overrideAdvance = false;
   particles = "LavaFireParticle";

   uiName = "Magma Fire";
};

function createLavaEmitter(%pos)
{
	%p = new ParticleEmitterNode()
	{
		datablock = genericEmitterNode;
		emitter = LavaFireEmitter;
		position = %pos;
		normal = 0;
	};
	missionCleanup.Add(%p);
	schedule(6000, 0, removeLavaEmitter, %p);
}

function removeLavaEmitter(%obj)
{
	if(isobject(%obj)) //In case they've changed the map, they won't get forty thousand lines of console spam.
		%obj.delete();
}

function generateRandomEmitters() //A cool effect of fire shooting up from the lava.
{
	if($Server::MissionName !$= "Slate Lavapit")
		return;
	%pos = getRandom(-384, 384) SPC getRandom(-384, 384) SPC "-10"; //Just do this relatively close to the main area.
	createLavaEmitter(%pos);
	$LavaSchedule = schedule($LavaFireTime, 0, generateRandomEmitters);
}
schedule(2000, 0, generateRandomEmitters); //Schedule it so it starts after the mission starts loading.

datablock DecalData(LavaTextureDownloader) //Because Torque deems water unimportant and we need to send it to them another way.
{
	textureName = "./lava";
};